#
# spec file for package libica
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
%define flavor openssl1_1%{nil}

%if "%{flavor}" == "openssl1_1"
Name:           libica-%{flavor}
%else
Name:           libica
%endif
Version:        4.3.1
Release:        150600.4.16.1
Summary:        Library interface for the IBM Cryptographic Accelerator device driver
License:        CPL-1.0
Group:          Hardware/Other
URL:            https://github.com/opencryptoki/libica
Source:         https://github.com/opencryptoki/libica/archive/refs/tags/v%{version}.tar.gz#/libica-%{version}.tar.gz
Source1:        README.SUSE
Source2:        sysconfig.z90crypt
Source3:        z90crypt
Source4:        z90crypt.service
Source5:        libica-rpmlintrc
###
Patch01:        libica-FIPS-make-it-possible-to-specify-fipshmac-binary.patch
Patch99:        libica-sles15sp5-FIPS-hmac-key.patch
%if "%{flavor}" == "openssl1_1"
#PATCH-FIX-OPENSUSE bsc#1221627 Rename the hmac files for the openssl1_1 flavor
Patch100:       libica-openssl1_1.patch
%endif
###
Patch110:       libica-01-fips-update-remove-sigVer-from-fips-ECDSA-kat.patch
Patch111:       libica-02-fips-update-Change-service-indicator-implementation.patch
Patch112:       libica-03-fips-update-Dynamically-update-service-indicator-based-on-IV-usage.patch
Patch113:       libica-04-fips-update-provide-test-for-dynamic-service-indicator.patch
###
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fipscheck
BuildRequires:  gcc-c++
BuildRequires:  libtool
%if "%flavor" == "openssl1_1"
BuildRequires:  libopenssl-1_1-devel
BuildRequires:  openssl-1_1
#We need openssl for HMAC computation, see 8947ac1a
BuildRequires:  openssl
%else
BuildRequires:  openssl-devel
BuildRequires:  openssl
%endif
Requires(post): %fillup_prereq
ExclusiveArch:  s390 s390x

%description
This package contains the interface library routines used by IBM
modules to interface with the IBM eServer Cryptographic Accelerator
(ICA).

%if "%flavor" == "openssl1_1"
%package -n libica4-openssl1_1
%else
%package -n libica4
%endif
Summary:        Library interface for the IBM Cryptographic Accelerator
Group:          System/Libraries
%if "%flavor" == "openssl1_1"
# Recommends:     libica-openssl1_1-tools
Recommends:     libica-openssl1_1-tools
%else
# Recommends:     libica-tools
Recommends:     libica-tools
%endif

%if "%flavor" == "openssl1_1"
%description -n libica4-openssl1_1
%else
%description -n libica4
%endif
This package contains the interface library routines used by IBM
modules to interface with the IBM eServer Cryptographic Accelerator
(ICA).

%package tools
Summary:        Utilities for the IBM Cryptographic Accelerator
Group:          Hardware/Other
Obsoletes:      libica < %{version}-%{release}
Obsoletes:      libica-2_3_0 < %{version}-%{release}
Obsoletes:      libica2 < %{version}-%{release}
Obsoletes:      libica3 < %{version}-%{release}
Provides:       libica = %{version}-%{release}
Provides:       libica-2_3_0 = %{version}-%{release}
Provides:       libica-plugin = %{version}-%{release}
Provides:       libica2 = %{version}-%{release}
Provides:       libica3 = %{version}-%{release}
%if "%flavor" == "openssl1_1"
Conflicts:      libica-tools
%else
Conflicts:      libica-openssl1_1-tools
%endif

%description tools
This package contains command-line utilities to inspect the IBM
eServer Cryptographic Accelerator (ICA).

%package        devel
Summary:        Development files for the ICA device driver interface library
Group:          Development/Libraries/C and C++
Obsoletes:      libica-2_1_0-devel < %{version}-%{release}
Provides:       libica-2_1_0-devel = %{version}-%{release}
Obsoletes:      libica-2_3_0-devel < %{version}-%{release}
Provides:       libica-2_3_0-devel = %{version}-%{release}
%if "%flavor" == "openssl1_1"
Requires:       libica4-openssl1_1 = %{version}
Requires:       libopenssl-1_1-devel
Conflicts:      libica-devel
%else
Requires:       libica4 = %{version}
Requires:       libopenssl-devel
Conflicts:      libica-openssl1_1-devel
%endif

%description devel
This package contains the interface library routines used by IBM
modules to interface with the IBM eServer Cryptographic Accelerator
(ICA).

This subpackage contains the necessary files to compile and link
using the libica library.

%package        devel-static
Summary:        Static Development files for the ICA device driver interface library
Group:          Development/Libraries/C and C++
%if "%flavor" == "openssl1_1"
Requires:       libica-openssl1_1-devel
Conflicts:      libica-devel-static
%else
Requires:       libica-devel
Conflicts:      libica-openssl1_1-devel-static
%endif

%description devel-static
This package contains the interface library routines used by IBM
modules to interface with the IBM eServer Cryptographic Accelerator
(ICA).

This RPM contains all the tools necessary to compile and link using
the libica library.

%prep
%autosetup -p 1 -n libica-%version

%build
autoreconf --force --install
# Remove -DNO_FIPS_CONFIG_LOAD flags to use the FIPS config file
%configure CPPFLAGS="-Iinclude -fPIC -DNO_FIPS_CONFIG_LOAD" CFLAGS="%{optflags} -fPIC -DNO_FIPS_CONFIG_LOAD" \
  --enable-fips

%make_build clean
%make_build FIPSHMAC=fipshmac BUILD_VERSION="FIPS-SUSE-%version-%release"

%define major %(echo %{version} | sed -e 's/[.].*//')

%{expand:%%global __os_install_post {%__os_install_post fipshmac %{buildroot}/%{_libdir}/*.so.%{version} }}

%install
%make_install FIPSHMAC=fipshmac
make fipsinstall FIPSHMAC=fipshmac DESTDIR=%{buildroot}
mkdir -p %{buildroot}%{_includedir}
cp -p include/ica_api.h %{buildroot}%{_includedir}
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcz90crypt
install -D %{SOURCE2} %{buildroot}%{_fillupdir}/sysconfig.z90crypt
install -D %{SOURCE3} %{buildroot}%{_prefix}/lib/systemd/scripts/z90crypt
install -D -m 644 %{SOURCE4} %{buildroot}%{_prefix}/lib/systemd/system/z90crypt.service
# It is installed 444 and then the __os_install_post cannot update it once the debuginfo is stripped
# We need it early because there is %{buildroot}/%{_libdir}/.*.so.%{major}.hmac symlink pointing at it
# and the dangling symlink test would fail
chmod 644 %{buildroot}/%{_libdir}/.*.so.%{version}.hmac

cp -a %{SOURCE1} .
rm -vf %{buildroot}%{_libdir}/libica*.la
rm -f %{buildroot}%{_datadir}/doc/libica/*
rmdir %{buildroot}%{_datadir}/doc/libica
%if "%flavor" == "openssl1_1"
# Rename the libraries for the openssl1_1 flavor
mv %{buildroot}%{_libdir}/{libica,%{name}}.so.%{version}
mv %{buildroot}%{_libdir}/{libica,%{name}}-cex.so.%{version}
mv %{buildroot}%{_libdir}/{libica,%{name}}.a
mv %{buildroot}%{_libdir}/{libica,%{name}}-cex.a
# Recreate symlinks, they can not be simply renamed
rm %{buildroot}%{_libdir}/libica.so.%{major}
ln -s %{name}.so.%{version} %{buildroot}%{_libdir}/%{name}.so.%{major}
rm %{buildroot}%{_libdir}/libica-cex.so.%{major}
ln -s %{name}-cex.so.%{version} %{buildroot}%{_libdir}/%{name}-cex.so.%{major}
rm %{buildroot}%{_libdir}/libica.so
ln -s %{name}.so.%{version} %{buildroot}%{_libdir}/%{name}.so
rm %{buildroot}%{_libdir}/libica-cex.so
ln -s %{name}-cex.so.%{version} %{buildroot}%{_libdir}/%{name}-cex.so
%else
### Comment below two lines to enable FIPS config file 'openssl3-fips.cnf'
# rm %{buildroot}/%{_sysconfdir}/libica/openssl3-fips.cnf
# rmdir %{buildroot}/%{_sysconfdir}/libica
%endif

%check
%make_build check FIPSHMAC=fipshmac

%pre tools
%service_add_pre z90crypt.service

%post tools
%service_add_post z90crypt.service
%{fillup_only -n z90crypt}

%preun tools
%service_del_preun z90crypt.service

%postun tools
%service_del_postun z90crypt.service

%if "%flavor" == "openssl1_1"
%post   -n libica4-openssl1_1 -p /sbin/ldconfig
%postun -n libica4-openssl1_1 -p /sbin/ldconfig

%files -n libica4-openssl1_1
%else
%post   -n libica4 -p /sbin/ldconfig
%postun -n libica4 -p /sbin/ldconfig

%files -n libica4
%endif

%{_libdir}/%{name}.so.%{version}
%{_libdir}/%{name}.so.%{major}
# Must be in here, otherwise openssl-ibmca does not find it via DSO_load() bsc#952871
%{_libdir}/%{name}.so
%{_libdir}/.%{name}.so.%{version}.hmac
%{_libdir}/.%{name}.so.%{major}.hmac
%{_libdir}/%{name}-cex.so.%{version}
%{_libdir}/%{name}-cex.so.%{major}
%{_libdir}/.%{name}-cex.so.%{version}.hmac
%{_libdir}/.%{name}-cex.so.%{major}.hmac

%if "%flavor" != "openssl1_1"
### Enable FIPS
%dir %{_sysconfdir}/libica
%{_sysconfdir}/libica/openssl3-fips.cnf
###
%endif

%files tools
%license LICENSE
%doc README.SUSE
%{_sbindir}/rcz90crypt
%attr(644,root,root) %{_fillupdir}/sysconfig.z90crypt
%{_bindir}/icainfo
%{_bindir}/icainfo-cex
%{_bindir}/icastats
%{_mandir}/man1/icainfo.1%{?ext_man}
%{_mandir}/man1/icainfo-cex.1%{?ext_man}
%{_mandir}/man1/icastats.1%{?ext_man}
%dir %{_prefix}/lib/systemd/scripts
%{_prefix}/lib/systemd/scripts/z90crypt
%{_prefix}/lib/systemd/system/z90crypt.service

%files devel
%{_includedir}/ica_api.h
%{_libdir}/%{name}-cex.so

%files devel-static
%{_libdir}/%{name}.a
%{_libdir}/%{name}-cex.a

%changelog
* Wed Nov 13 2024 nikolay.gueorguiev@suse.com
- Applied updated patches (bsc#1231302, bsc#1231304)
  * libica-03-fips-update-Dynamically-update-service-indicator-based-on-IV-usage.patch
  * libica-04-fips-update-provide-test-for-dynamic-service-indicator.patch
* Tue Nov 12 2024 nikolay.gueorguiev@suse.com
- Applied updated patches (bsc#1231302, bsc#1231304)
  * libica-02-fips-update-Change-service-indicator-implementation.patch
  * libica-03-fips-update-Dynamically-update-service-indicator-based-on-IV-usage.patch
  * libica-04-fips-update-provide-test-for-dynamic-service-indicator.patch
* Wed Nov  6 2024 nikolay.gueorguiev@suse.com
- Applied additional patches (bsc#1231302)
  * libica-03-fips-update-Dynamically-update-service-indicator-based-on-IV-usage.patch
  * libica-04-fips-update-provide-test-for-dynamic-service-indicator.patch
* Tue Oct 29 2024 nikolay.gueorguiev@suse.com
- Applied patches (bsc#1231302, bsc#1231303, bsc#1231304, bsc#1231305)
  * libica-01-fips-update-remove-sigVer-from-fips-ECDSA-kat.patch
  * libica-02-fips-update-Change-service-indicator-implementation.patch
* Tue Oct 29 2024 nikolay.gueorguiev@suse.com
- Upgrade libica to version 4.3.1 (jsc#PED-9560, jsc#PED-10289, jsc#PED-3276)
  * Various bug fixes and housekeeping
- Removed obsolete patches
  * libica-4.3.0-01-disable-CEX-usage-in-OpenSSL-for-all-tests.patch
  * libica-4.3.0-02-correct-rc-handling-with-s390_pcc-function.patch
  * libica-4.3.0-03-Use-__asm__-instead-of-asm.patch
* Wed Oct 23 2024 nikolay.gueorguiev@suse.com
- Amended the .spec file (bsc#1231999)
  * Changed Recommends to Requires for libica-tools for both flavors
    openssl-3 and openssl-1 (libica-tools and libica-openssl1_1-tools)
* Mon Sep 16 2024 nikolay.gueorguiev@suse.com
- Build with the new fipscheck (bsc#1227136)
* Tue Sep 10 2024 nikolay.gueorguiev@suse.com
- Amended the .spec file (bsc#1227136)
  * Added a flag '-DNO_FIPS_CONFIG_LOAD' to CPPFLAGS and CFLAGS
  * Do not ship the config file '/etc/libica/openssl3-fips.cnf'
* Wed Jul  3 2024 nikolay.gueorguiev@suse.com
- Upgrade to version 4.3.0 (bsc#1227136)
  * [FEATURE] New API function ica_allow_external_gcm_iv_in_fips_mode
  * [PATCH] bug fixes
- Applied patches
  * libica-4.3.0-01-disable-CEX-usage-in-OpenSSL-for-all-tests.patch
  * libica-4.3.0-02-correct-rc-handling-with-s390_pcc-function.patch
  * libica-4.3.0-03-Use-__asm__-instead-of-asm.patch
- Amended the .spec file to enable FIPS
* Wed Apr 17 2024 otto.hollmann@suse.com
- Add multibuild flavor to provide library compiled against openssl-1_1
  [bsc#1221627]
  * Add libica-openssl1_1.patch
* Fri Oct  6 2023 nikolay.gueorguiev@suse.com
- Upgrade to version 4.2.3 (jsc#PED-5446)
  * Add OPENSSL_init_crypto in libica constructor
  * Remove deprecated ioctl Z90STAT_STATUS_MASK
  * Bug fixes
* Tue May 23 2023 nikolay.gueorguiev@suse.com
- Upgrade to version 4.2.2 (jsc#PED-3277, jsc#PED-3276)
  - [UPDATE] syslog msgs only in error cases
  - [UPDATE] don't count statistics in fips power-on self tests
  - [PATCH] various fixes and some new tests
* Fri Apr 28 2023 otto.hollmann@suse.com
- Remove file /etc/libica/openssl3-fips.cnf - we don't support FIPS yet
* Thu Apr 27 2023 dimstar@opensuse.org
- Prefix /etc/libica with %%dir to ensure we don't package
  unversioned files in libica4, as otherwise we violate SLPP.
* Thu Apr 27 2023 otto.hollmann@suse.com
- Add /etc/libica directory into %%files section.
* Fri Feb 17 2023 nikolay.gueorguiev@suse.com
- Upgrade to version 4.2.1 (jsc#PED-2872)
  - [PATCH] fix regression opening shared memory
* Mon Jan 16 2023 meissner@suse.com
- Upgrade to version 4.2.0 (jsc#PED-581, bsc#1202365).
  - [FEATURE] Display build info via icainfo -v
  - [FEATURE] New API function ica_get_build_version()
  - [FEATURE] Display fips indication via icainfo -f
  - [FEATURE] New API function ica_get_fips_indicator()
  - [FEATURE] New API function ica_aes_gcm_initialize_fips()
  - [FEATURE] New API function ica_aes_gcm_kma_get_iv()
  - [FEATURE] New API function ica_get_msa_level()
  - [PATCH] icainfo: check for malloc error when getting functionlist
* Tue Oct 11 2022 mpost@suse.com
- Upgrade to version 4.1.1 (jsc#PED-581, bsc#1202365).
  v4.1.1
  - [PATCH] Fix aes-xts multi-part operations
    [PATCH] Fix make dist
  v4.1.0
  - [FEATURE] FIPS: make libica FIPS 140-3 compliant
    [FEATURE] New API function ica_ecdsa_sign_ex()
    [FEATURE] New icainfo output option -r
  - [PATCH] Various bug fixes
- Removed the following obsolete files:
  baselibs.conf
  icaioctl.h
* Mon Sep 12 2022 mpost@suse.com
- Upgraded to version 4.0.3 (jsc#PED-581, jsc#PED-621, jsc#PED-629)
  v4.0.3
  - [PATCH] Reduce the number of open file descriptors
  - [PATCH] Various bug fixes
  v4.0.2
  - [PATCH] Various bug fixes
  v4.0.1
  - [PATCH] Various bug fixes
  - [PATCH] Compute HMAC from installed library
  v4.0.0
  - [UPDATE] NO_SW_FALLBACKS is now the default for libica.so
    [UPDATE] Removed deprecated API functions including tests
    [UPDATE] Introduced 'const' for some API function parameters
    [FEATURE] icastats: new parm -k to display detailed counters
- Replaced libica-sles15sp2-FIPS-hmac-key.patch with an updated
  version named libica-sles15sp5-FIPS-hmac-key.patch.
- Updated the libica-rpmlintrc file to suppress warnings about the
  libica-cex hmac files being hidden.
- Updated the spec file to properly both obsolete and provide two
  older versions of the package.
* Tue Oct 19 2021 mpost@suse.com
- Upgrade to version 3.9.0 (jsc#SLE-18454, jsc#SLE-18564)
  - [FEATURE] Add support for OpenSSL 3.0
  - [FEATURE] icainfo: new parm -c to display available EC curves
- Replaced the obsolete PreReq: %%fillup_prereq
  with                  Requires(post): %%fillup_prereq
  in the spec file.
* Mon Jun  7 2021 msuchanek@suse.com
- Update to version 3.8.0 (jsc#SLE-18334)
  - [FEATURE] provide libica-cex module to satisfy special security requirements
  - [FEATURE] FIPS: enforce the HMAC check
- Remove upstreamed patches:
  - libica-sles15sp2-FIPS-add-SHA3-KATs-to-fips_powerup_tests.patch
  - libica-sles15sp2-FIPS-skip-SHA3-tests-if-running-on-hardware-without-.patch
  - libica-sles15sp2-Zeroize-local-variables.patch
- Remove patches obsoleted by upstrea developent:
  * FIPS: Find libica from phdrs.
  - libica-sles15sp2-FIPS-use-full-library-version-for-hmac-filename.patch
  * FIPS: enforce the hmac check
  - libica-sles15sp2-FIPS-fix-inconsistent-error-handling.patch
- Fix up tests and hmac generation
  + libica-FIPS-make-it-possible-to-specify-fipshmac-binary.patch
- Remove obsolete attributes from filelists
* Fri Sep 18 2020 mpost@suse.com
- Upgraded to version 3.7.0 (jsc#SLE-13708)
  * Version 3.7.0
  - [FEATURE] FIPS: Add HMAC based library integrity check
  - [PATCH] icainfo: bugfix for RSA and EC related info for software column.
  - [PATCH] FIPS: provide output iv in cbc-cs decrypt as required by FIPS tests
  - [PATCH] FIPS: Fix DES and TDES key length
  - [PATCH] icastats: Fix stats counter format
  * Version 3.6.1
  - [PATCH] Fix x25519 and x448 handling of non-canonical values
- Removed the following obsolete patches
  * libica-sles15sp2-x25519-x448-fix-handling-of-non-canonical-values.patch
  * libica-sles15sp2-Fix-DES-and-TDES-key-length.patch
  * libica-sles15sp2-FIPS-provide-output-iv-as-required-by-FIPS-tests.patch
  * libica-sles15sp2-icainfo-bugfix-for-RSA-and-EC-related-info-for-softw.patch
  * libica-sles15sp2-Build-with-pthread-flag.patch
  * libica-sles15sp2-FIPS-introduce-HMAC-based-library-integrity-check.patch
  * libica-sles15sp2-FIPS-HMAC-based-library-integrity-check-addon.patch
  * libica-sles15sp2-FIPS-HMAC-based-library-integrity-check-rename-variables.patch
* Tue Sep 15 2020 mpost@suse.com
- Fix lack of SHA3 KATs in "make check" processing (bsc#1175277)
  * Added libica-sles15sp2-FIPS-add-SHA3-KATs-to-fips_powerup_tests.patch
  * Added libica-sles15sp2-FIPS-skip-SHA3-tests-if-running-on-hardware-without-.patch
- Fix FIPS hmac check (bsc#1175356).
  * Update FIPS support to upstream
  - Refresh libica-sles15sp2-FIPS-introduce-HMAC-based-library-integrity-check.patch
    from upstream.
  - Add libica-sles15sp2-Build-with-pthread-flag.patch
  - Add libica-sles15sp2-FIPS-HMAC-based-library-integrity-check-addon.patch
  - Add libica-sles15sp2-FIPS-HMAC-based-library-integrity-check-rename-variables.patch
  - Add libica-sles15sp2-FIPS-use-full-library-version-for-hmac-filename.patch
  * FIPS check should fail when hmac is missing
  - Add libica-sles15sp2-FIPS-fix-inconsistent-error-handling.patch
  - Create an hmac for the selftest
  - Check that selftest fails without a hmac
  - Hash libica.so.3 rather than libica.so.3.6.0
  * Fix hmac key format. It should be hexadecimal, not ASCII
  - Refresh libica-sles15sp2-FIPS-hmac-key.patch
- Fix Some internal variables used to store sensitive information
  (keys) were not zeroized before returning to the calling application.
  (bsc#1175357)
  * Added libica-sles15sp2-Zeroize-local-variables.patch
- Updated libica-rpmlintrc to eliminate the warning about the HMAC file
  being a hidden file. It is supposed to be hidden.
* Thu May  7 2020 mpost@suse.com
- Added the following patches for FIPS certification (bsc#1162533)
  * libica-sles15sp2-FIPS-introduce-HMAC-based-library-integrity-check.patch
  * libica-sles15sp2-FIPS-hmac-key.patch
- Added a BuildRequires for the fipscheck package.
- Made a couple of changes to the spec file based upon recommendations
  by spec-cleaner.
* Wed Apr  8 2020 mpost@suse.com
- Added the following patches for FIPS certification.
  * libica-sles15sp2-Fix-DES-and-TDES-key-length.patch
    (bsc#1166071) Although a DES key has only 56 effective bits,
    all 64 bits must be considered, because the parity bits are
    spread over all 8 bytes of the key.
  * libica-sles15sp2-FIPS-provide-output-iv-as-required-by-FIPS-tests.patch
    (bsc#1166210) FIPS tests require the output iv to be the iv
    resulting from decrypting the last block with a zero iv as input.
  * libica-sles15sp2-icainfo-bugfix-for-RSA-and-EC-related-info-for-softw.patch
    (bsc#1166224) The output from icainfo never shows 'yes' for
    RSA ME, RSA CRT, ECDH, ECDSA sign, ECDSA verify, and ECKGEN,
    due to the missing ICA_FLAG_SW flag in the icaList.
* Thu Nov 14 2019 mpost@suse.com
- Added libica-sles15sp2-x25519-x448-fix-handling-of-non-canonical-values.patch
  (bsc#1156768)
* Tue Oct 15 2019 mpost@suse.com
- Upgraded to version 3.6.0 (jsc#SLE-7584)
  * [FEATURE] Add MSA9 CPACF support for Ed25519, Ed448, X25519 and X448
* Fri Aug 30 2019 mpost@suse.com
- Upgraded to version 3.5.0 (Fate#327840)
  - [FEATURE] Add MSA9 CPACF support for ECDSA sign/verify
- Reworked how libica-tools loads and unloads kernel modules to
  avoid spurious error messages (bsc#1134004):
  * Converted the boot.z90crypt sysV init script to a systemd unit
  file.
  * Removed any references to insserv in the spec file.
  * Updated the z90crypt script itself to properly load and unload
  the kernel modules as they exist today.
  * Eliminated the obsolete libica-SuSE.tar.bz2 archive.
- Updated the README.SUSE file to reflect the change from sysV init
  style script to systemd.
- Made numerous changes to the spec file, based on the output from
  the spec-cleaner command.
* Wed Jul 24 2019 mpluskal@suse.com
- Run testsuite during build
* Thu Nov 15 2018 mpost@suse.com
- Upgraded to version 3.4.0 (Fate#325690)
  * v3.4.0
    [FEATURE] Add SHA-512/224 and SHA-512/256 support
- Dropped obsolete patch Add-non-executable-gnu-stack-markings-in-the-assembl.patch
- Made numerous updates to spec file based on spec-cleanup run.
* Wed Nov 14 2018 mpost@suse.com
- Upgraded to version 3.3.3 (Fate#325690)
  * v3.3.3
    [PATCH] Various bug fixes
  * v3.3.2
    [PATCH] Skip ECC tests if required HW is not available
    [PATCH] Update spec file
  * v3.3.1
    [PATCH] Fix configure.ac to honour CFLAGS
  * v3.3.0
    [FEATURE] Add CEX supported elliptic-curve crypto interfaces
    [FEATURE] Add SIMD supported multiple-precision arithmetic interfaces
    [FEATURE] Add interface to enable/disable SW fallbacks
    [FEATURE] Add 'make check' target, test-suite rework
  * v3.2.1
    [FEATURE] Use z14 PRNO-TRNG to seed SHA512-DRBG.
    [PATCH] Various bug fixes.
- Dropped obsolete patch increment-icastats-counter-for-aes-gcm.patch
- Removed COPYING from %%files, since it is no longer in the tarball.
- Added Add-non-executable-gnu-stack-markings-in-the-assembl.patch
  (bsc#1103493).
- Made multiple changes to the spec file based on the output of
  spec-cleaner
* Mon Oct 22 2018 mpost@suse.com
- Added "Obsoletes: libica-2_3_0" to the libica-tools package to
  fix a problem with upgrading from SLES12 SP2 to either SLES12
  SP3/SP4, or SLES15. (bsc#1112655)
* Tue Sep 11 2018 mpost@suse.com
- Added "Obsoletes: libica2" to the libica-tools package to fix
  a problem with upgrading from SLES12 SP2 to either SLES12
  SP3/SP4, or SLES15. (bsc#1046435, bsc#1104638)
* Wed Apr 18 2018 mpost@suse.com
- Added increment-icastats-counter-for-aes-gcm.patch (bsc#1086756)
- Updated boot.z90crypt script to fix a problem with the modprobe
  command not being found. (bsc#1040229).
- Added "Recommends: libica-tools" (bsc#1046435).
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Oct  4 2017 mpost@suse.com
- Added "--enable-fips" to the %%configure parms (Fate#324115)
* Fri Sep 22 2017 mpost@suse.com
- Upgraded to version 3.2 (Fate#321517)
  * v3.2.0
    [FEATURE] New AES-GCM interface.
    [UPDATE] Add symbol versioning.
  * v3.1.1
    [PATCH] Various bug fixes related to old and new AES-GCM implementations.
    [UPDATE] Add SHA3 test cases. Improved and extended test suite.
  * v3.1.0
    [FEATURE] Add KMA support for AES-GCM.
    [FEATURE] Add SHA-3 support.
    [PATCH] Reject RSA keys with invalid key-length.
    [PATCH] Allow zero output length for ica_random_number_generate.
    [PATCH] icastats: Correct owner of shared segment when root creates it.
  * Removed the following obsolete patches:
    libica-3.0.2-01-fix-old-aes-gcm-decrypt-code-path.patch
    libica-3.0.2-02-fix-aes-ccm-encrypt-code-path.patch
    libica-3.0.2-03-fix-aes-ctr.patch
    libica-3.0.2-04-fix-aes-gcm-to-allow-zero-pt-ct-length.patch
* Wed Sep 13 2017 mpost@suse.com
- libica: AES-GCM/CCM sometimes compute wrong tag values (bsc#1058567)
  - Added the following patches (bsc#1058567)
  - libica-3.0.2-01-fix-old-aes-gcm-decrypt-code-path.patch
  - libica-3.0.2-02-fix-aes-ccm-encrypt-code-path.patch
  - libica-3.0.2-03-fix-aes-ctr.patch
  - libica-3.0.2-04-fix-aes-gcm-to-allow-zero-pt-ct-length.patch
* Thu Jun  1 2017 fcrozat@suse.com
- baselibs.conf doesn't need any additional provides/conflicts for
  libica3.
* Fri May 12 2017 fcrozat@suse.com
- Update baselibs.conf with proper name for library package name,
  stop providing/obsoleting libica-2_1_0/libica-2_3-0.
* Tue May  9 2017 mpost@suse.com
- Upgraded to version 3.0.2 (Fate#322025).
  - v3.0.2
  - Fix locking callbacks for openSSL APIs.
  - v3.0.1
  - Fixed msa level detection on zEC/BC12 GA1 and predecessors.
  - v3.0.0
  - Added FIPS mode.
  - Sanitized exported symbols.
  - Removed deprecated APIs. Marked some APIs as deprecated.
  - Adapted to OpenSSL v1.1.0.
  - RSA key generation is thread-safe now.
- Removed the following obsolete patches:
  - fix-initialization-of-s390-hardware-switches-1.patch
  - fix-initialization-of-s390-hardware-switches-2.patch
  - fix-msa-level-detection.patch
  - fix-segfault-during-multithread-keygen.patch
  - rng-performance.patch
* Fri Mar 31 2017 mpost@suse.com
- Made the following packaging changes:
  - Implemented the shared library packaging guidelines.
  - Consolidated double invocation of %%setup into just one.
  - Dropped redundant %%ifarch, the package is already ExclusiveArch.
  - Updated descriptions.
- Added an libica-rpmlintrc file.
* Wed Nov 30 2016 mpost@suse.com
- Added the following two patches:
  - fix-segfault-during-multithread-keygen.patch (bsc#991485)
  - fix-msa-level-detection.patch (bsc#1010927)
* Tue Aug  2 2016 mpost@suse.com
- Added rng-performance.patch (bsc#990850).
* Tue Jun 14 2016 mpost@suse.com
- Updated baselibs.conf to obsolete prior versions of the 32bit
  package. (bsc#983897):
  provides "libica-<targettype> = <version>"
  obsoletes "libica-<targettype> < <version>"
  provides "libica-2_1_0-<targettype> = <version>"
  obsoletes "libica-2_1_0-<targettype> < <version>"
  provides "libica-2_3_0-<targettype> = <version>"
  obsoletes "libica-2_3_0-<targettype> < <version>"
* Wed May 18 2016 mpost@suse.com
- Added fix-initialization-of-s390-hardware-switches-1.patch and
  fix-initialization-of-s390-hardware-switches-2.patch (bsc#980548)
* Mon Feb 22 2016 mpost@suse.com
- Upgraded to version 2.6.2 (FATE#319610).
- Renamed /etc/init.d/z90crypt to boot.z90crypt to conform to
  naming standards.
- Found the original location of the icaioctl.h file and downloaded
  it to replace what we had previously.
- Removed the unnecessary libica2.la file
- Removed unnecessary Requires for glibc-devel
- Added Requires libica2 to the -devel package
- Converted call to configure to %%configure macro
- Removed obsolete and unnecessary INSROOT and bindir parameters
  from the make install command
* Fri Nov  6 2015 pth@suse.de
- Add Provides/Obsoletes for libica-2_3_0 so that the package from
  SLE12 GA is replaced (bsc#953096).
* Wed Nov  4 2015 meissner@suse.com
- move the .so file to the mainpackage, the openssl-ibmca engine
  will only load "libica.so" (bsc#952871)
* Mon Aug 17 2015 jjolly@suse.com
- Update to libica v2.4.2 (FATE#318035)
- Removed outdated libica-aes_ccm-31-bit-compatibility.patch
- Moved init script into libica-SuSE.tar.bz2 archive
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Wed Aug 13 2014 jjolly@suse.com
- Moved z90crypt out of useless libica-SuSE.tar.bz2 tarball to root
- Removed libica-SuSE.tar.bz2
- z90crypt now starts and stops ap kernel module (bnc#888943)
* Tue Mar 18 2014 jjolly@suse.com
- libica-aes_ccm-31-bit-compatibility.patch: AES_CCM:
  fixed 64/31 bit compatibility
* Thu Mar  6 2014 ro@suse.de
- add obsoletes and provides for older libica versions
* Wed Mar  5 2014 ro@suse.de
- update to 2.3.0 (fate#315342)
- obsolete/upstreamed patches:
  libica-2_1_0-fix_temporary_buffer_allocation_in_ica_get_version.patch
  libica-2_1_0-msa4-extension.patch
  libica-2_1_0-synchronize_shared_memory_ref_counting.patch
* Wed Feb 19 2014 jjolly@suse.com
- Added COPYING to %%files
* Tue Feb 18 2014 jjolly@suse.com
- Fixed build dependency errors by requiring autoconf, automake
  and libtool
- Changed license to CPL-1.0
- Created devel package
* Fri Dec 21 2012 uli@suse.com
- Support for MSA4 extension (bnc#794518, fate#314078)
* Thu Oct  6 2011 uli@suse.com
- synchronize shared memory reference counting for library
  statistics (bnc#719659)
- fix temporary buffer allocation in ica_get_version() (bnc#719660)
* Tue Jun 14 2011 uli@suse.de
- update -> 2.1.0 (fate#311914)
* Fri Jan 23 2009 jjolly@suse.de
- Moved icainfo into /usr/bin (bnc#448643)
* Tue Jan 13 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Nov  5 2008 ro@suse.de
- fix build on all platforms
* Sun Nov  2 2008 jjolly@suse.de
- Added CPL license to include/z90crypt.h, removed GPL reference
  (This patch is upstream)
* Wed Oct 15 2008 jjolly@suse.de
- Changed package name to libica-1_3_9 to conform to rpmlint
  requirements. (bnc#433432)
* Thu Sep 25 2008 jjolly@suse.de
- Removed soname filter for rpmlint
- Several RPM fixes to help satisfy rpmlint
* Fri Sep 12 2008 jjolly@suse.de
- Updated to libica 1.3.9
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Aug  9 2007 olh@suse.de
- remove inclusion of linux/config.h
* Mon Mar 12 2007 uli@suse.de
- z90crypt: handle errors (bug #247799)
* Mon May 22 2006 aj@suse.de
- Add gcc-c++ to BuildRequires.
* Fri May 19 2006 ro@suse.de
- fix build for the rest of platforms
* Fri May 19 2006 hare@suse.de
- Update to libica 1.3.7 (#160036 - LTC22571)
* Fri Apr 21 2006 hare@suse.de
- Increasing # of open handles with symmetric crypto support
  (#165323 - LTC23095)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 14 2005 ro@suse.de
- include string.h and unistd.h in icalinux.c
* Mon Dec 12 2005 hare@suse.de
- Port package from SLES9 SP3
- Update to libica 1.3.6-rc3.
* Wed Nov  2 2005 hare@suse.de
- Close all filehandles (#130060 - LTC19221).
* Wed Oct  5 2005 uli@suse.de
- downgrade to libica 1.3.6-rc2 (contains AES software fallback,
  bug #117336)
* Thu Sep 29 2005 hare@suse.de
- Update to libica 1.3.6 (#117336)
* Fri Sep 23 2005 ro@suse.de
- fix implicit declaration
* Wed Aug 31 2005 ihno@suse.de
- Changing the default value from 0 to -1 in rcz90crypt (#114371)
* Mon May 23 2005 hare@suse.de
- Finally fix 'reload' messages (#81824 - LTC15733).
* Fri May 20 2005 hare@suse.de
- Fix sigill patch.
* Wed May 18 2005 hare@suse.de
- Remove printf output from sigill patch (#81829 - LTC15731).
* Tue May 10 2005 hare@suse.de
- Use correct default value for z90crypt (#81825 - LTC15732).
* Mon May  9 2005 hare@suse.de
- Fix messages for 'reload' (#81824 - LTC15733).
* Tue Feb  8 2005 hare@suse.de
- Fixed SIGILL on z900 (#46422).
* Fri Jul 23 2004 hare@suse.de
- Fixed range for 'domain' parameter in sysconfig.z90crypt (#42005).
* Wed Jul 14 2004 hare@suse.de
- Fix module loading error (#42006).
- Add sysconfig variable to set the 'domain' parameter (#42005).
* Wed Jun 23 2004 uli@suse.de
- update -> 1.3.5-3 (bug #42122)
* Mon May 24 2004 bk@suse.de
- Update README.SuSE and correct name as well
- Use modprobe instead of insmod and fix module load error(#40526)
- Fix error checking for no hardware found case and hw error on load
* Fri May  7 2004 hare@suse.de
- Update Readme again for the correct name (SUSE LINUX Server).
- Moved README.SuSE to README.SUSE.
* Fri May  7 2004 hare@suse.de
- Update Readme to refer to the correct name (SUSE Linux Server).
* Thu May  6 2004 hare@suse.de
- Update to 1.3.5-2 (#38511, #39693).
- Update Readme to refer to SUSE Linux Server instead of
  SuSE Linux Enterprise Server.
* Thu Apr  1 2004 hare@suse.de
- Update to 1.3.5
- export CFLAGS & CPPFLAGS for configure
- Exclude S/390-specific files for other archs (#37183)
* Fri Jan 16 2004 ro@suse.de
- add "-I./include" to CFLAGS and use RPM_OPT_FLAGS
* Tue Jan 13 2004 adrian@suse.de
- fix build
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Wed Jul 30 2003 poeml@suse.de
- update to 1.3.4
* Sun Jul 27 2003 poeml@suse.de
- update to 1.3.2
* Fri Jul 11 2003 poeml@suse.de
- update to 1.3.1:
  now supports DES, TDES and SHA, as well as RSA.
- throw libica.patch away, since autoversion and Makefile.am have
  similar changes now, and the renaming from _LINUX_S390_ to
  __s390__ is not really necessary
- use %%defattr
- checked that icaioctl.h is still current
- dump the bin-only z90crypt-2.4.7-s390-2.tar.gz which has gone
  open source meanwhile and comes with the kernel sources
* Thu Oct 31 2002 froh@suse.de
- added documentation how to set up crypto hardware support,
  esp. S/390 and zSeries. (#16011, #22056)
* Thu Oct 10 2002 froh@suse.de
- upgraded to version 1.2 as requested by IBM to make openCryptoki 1.5
  actually work. (#20737)
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Wed Jul 31 2002 froh@suse.de
- fixed src/Makefile.am and ugly ./autoversion to honor %%_lib and
  to build on non-s390
* Tue Jul 30 2002 froh@suse.de
- updated to current libica
- hacked in icaioctl.h for build, 'til we have the module in the
  kernel.
* Sat Jul 27 2002 adrian@suse.de
- add %%run_ldconfig
* Tue May  7 2002 ro@suse.de
- fix for current automake/autoconf
* Sat Apr 27 2002 ro@suse.de
- removed old fillup-template and START_ variable
* Wed Mar 27 2002 ihno@suse.de
- modified etc/init.d/z90crypt-script to report result at start.
* Tue Feb  5 2002 froh@suse.de
- Added openssl to #neededforbuild, which is needed in addition to
  openssl-devel
* Wed Jan 30 2002 froh@suse.de
- initial version
